@@ -91,7 +91,7 @@ template <int cc>
 typename GridImp::template Codim<cc>::Entity
 UGGridEntity<0,dim,GridImp>::subEntity ( int i ) const
 {
-  assert(i>=0 && i < subEntities(cc));
+  assert(i>=0 && i < int(subEntities(cc)));
 
   typename UG_NS<dim>::template Entity<cc>::T* subEntity;
 
@@ -171,14 +171,14 @@ UGGridEntity < 0, dim ,GridImp >::hbegin(int maxlevel) const
     for (int i=0; i<UG_NS<dim>::nSons(target_); i++)
       it.elementStack_.push(sonList[i]);
 
-    it.virtualEntity_.setToTarget( it.elementStack_.empty()
+    it.entity_.impl().setToTarget( it.elementStack_.empty()
                                    ? nullptr
                                    : it.elementStack_.top(),
                                    gridImp_
                                    );
 
   } else {
-    it.virtualEntity_.setToTarget(nullptr,nullptr);
+    it.entity_.impl().setToTarget(nullptr,nullptr);
   }
 
   return it;
